Class: Google::Apis::OsconfigV1alpha::InventoryItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

A single piece of inventory on a VM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventoryItem

Returns a new instance of InventoryItem.



581
582
583
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_packageGoogle::Apis::OsconfigV1alpha::InventorySoftwarePackage

Software package information of the operating system. Corresponds to the JSON property availablePackage



549
550
551
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 549

def available_package
  @available_package
end

#create_timeString

When this inventory item was first detected. Corresponds to the JSON property createTime

Returns:

  • (String)


554
555
556
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 554

def create_time
  @create_time
end

#idString

Identifier for this item, unique across items for this VM. Corresponds to the JSON property id

Returns:

  • (String)


559
560
561
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 559

def id
  @id
end

#installed_packageGoogle::Apis::OsconfigV1alpha::InventorySoftwarePackage

Software package information of the operating system. Corresponds to the JSON property installedPackage



564
565
566
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 564

def installed_package
  @installed_package
end

#origin_typeString

The origin of this inventory item. Corresponds to the JSON property originType

Returns:

  • (String)


569
570
571
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 569

def origin_type
  @origin_type
end

#typeString

The specific type of inventory, correlating to its specific details. Corresponds to the JSON property type

Returns:

  • (String)


574
575
576
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 574

def type
  @type
end

#update_timeString

When this inventory item was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


579
580
581
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 579

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



586
587
588
589
590
591
592
593
594
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 586

def update!(**args)
  @available_package = args[:available_package] if args.key?(:available_package)
  @create_time = args[:create_time] if args.key?(:create_time)
  @id = args[:id] if args.key?(:id)
  @installed_package = args[:installed_package] if args.key?(:installed_package)
  @origin_type = args[:origin_type] if args.key?(:origin_type)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end