Class: Google::Apis::OsconfigV1alpha::InventorySoftwarePackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Software package information of the operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySoftwarePackage

Returns a new instance of InventorySoftwarePackage.



720
721
722
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apt_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property aptPackage



667
668
669
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 667

def apt_package
  @apt_package
end

#cos_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property cosPackage



673
674
675
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 673

def cos_package
  @cos_package
end

#googet_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property googetPackage



679
680
681
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 679

def googet_package
  @googet_package
end

#qfe_packageGoogle::Apis::OsconfigV1alpha::InventoryWindowsQuickFixEngineeringPackage

Information related to a Quick Fix Engineering package. Fields are taken from Windows QuickFixEngineering Interface and match the source names: https://docs. microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering Corresponds to the JSON property qfePackage



686
687
688
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 686

def qfe_package
  @qfe_package
end

#windows_applicationGoogle::Apis::OsconfigV1alpha::InventoryWindowsApplication

Contains information about a Windows application that is retrieved from the Windows Registry. For more information about these fields, see: https://docs. microsoft.com/en-us/windows/win32/msi/uninstall-registry-key Corresponds to the JSON property windowsApplication



693
694
695
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 693

def windows_application
  @windows_application
end

#wua_packageGoogle::Apis::OsconfigV1alpha::InventoryWindowsUpdatePackage

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated. Corresponds to the JSON property wuaPackage



701
702
703
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 701

def wua_package
  @wua_package
end

#yum_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property yumPackage



707
708
709
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 707

def yum_package
  @yum_package
end

#zypper_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property zypperPackage



713
714
715
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 713

def zypper_package
  @zypper_package
end

#zypper_patchGoogle::Apis::OsconfigV1alpha::InventoryZypperPatch

Details related to a Zypper Patch. Corresponds to the JSON property zypperPatch



718
719
720
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 718

def zypper_patch
  @zypper_patch
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



725
726
727
728
729
730
731
732
733
734
735
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 725

def update!(**args)
  @apt_package = args[:apt_package] if args.key?(:apt_package)
  @cos_package = args[:cos_package] if args.key?(:cos_package)
  @googet_package = args[:googet_package] if args.key?(:googet_package)
  @qfe_package = args[:qfe_package] if args.key?(:qfe_package)
  @windows_application = args[:windows_application] if args.key?(:windows_application)
  @wua_package = args[:wua_package] if args.key?(:wua_package)
  @yum_package = args[:yum_package] if args.key?(:yum_package)
  @zypper_package = args[:zypper_package] if args.key?(:zypper_package)
  @zypper_patch = args[:zypper_patch] if args.key?(:zypper_patch)
end