Class: Google::Apis::OsconfigV1alpha::InventoryWindowsUpdatePackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventoryWindowsUpdatePackage

Returns a new instance of InventoryWindowsUpdatePackage.



1091
1092
1093
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::OsconfigV1alpha::InventoryWindowsUpdatePackageWindowsUpdateCategory>

The categories that are associated with this update package. Corresponds to the JSON property categories



1048
1049
1050
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1048

def categories
  @categories
end

#descriptionString

The localized description of the update package. Corresponds to the JSON property description

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1053

def description
  @description
end

#kb_article_idsArray<String>

A collection of Microsoft Knowledge Base article IDs that are associated with the update package. Corresponds to the JSON property kbArticleIds

Returns:

  • (Array<String>)


1059
1060
1061
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1059

def kb_article_ids
  @kb_article_ids
end

#last_deployment_change_timeString

The last published date of the update, in (UTC) date and time. Corresponds to the JSON property lastDeploymentChangeTime

Returns:

  • (String)


1064
1065
1066
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1064

def last_deployment_change_time
  @last_deployment_change_time
end

#more_info_urlsArray<String>

A collection of URLs that provide more information about the update package. Corresponds to the JSON property moreInfoUrls

Returns:

  • (Array<String>)


1069
1070
1071
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1069

def more_info_urls
  @more_info_urls
end

#revision_numberFixnum

The revision number of this update package. Corresponds to the JSON property revisionNumber

Returns:

  • (Fixnum)


1074
1075
1076
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1074

def revision_number
  @revision_number
end

#support_urlString

A hyperlink to the language-specific support information for the update. Corresponds to the JSON property supportUrl

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1079

def support_url
  @support_url
end

#titleString

The localized title of the update package. Corresponds to the JSON property title

Returns:

  • (String)


1084
1085
1086
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1084

def title
  @title
end

#update_idString

Gets the identifier of an update package. Stays the same across revisions. Corresponds to the JSON property updateId

Returns:

  • (String)


1089
1090
1091
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1089

def update_id
  @update_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1096

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @kb_article_ids = args[:kb_article_ids] if args.key?(:kb_article_ids)
  @last_deployment_change_time = args[:last_deployment_change_time] if args.key?(:last_deployment_change_time)
  @more_info_urls = args[:more_info_urls] if args.key?(:more_info_urls)
  @revision_number = args[:revision_number] if args.key?(:revision_number)
  @support_url = args[:support_url] if args.key?(:support_url)
  @title = args[:title] if args.key?(:title)
  @update_id = args[:update_id] if args.key?(:update_id)
end