Class: Google::Apis::OsconfigV1alpha::ListInstanceOsPoliciesCompliancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

A response message for listing OS policies compliance data for all Compute Engine VMs in the given location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstanceOsPoliciesCompliancesResponse

Returns a new instance of ListInstanceOsPoliciesCompliancesResponse.



1187
1188
1189
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_os_policies_compliancesArray<Google::Apis::OsconfigV1alpha::InstanceOsPoliciesCompliance>

List of instance OS policies compliance objects. Corresponds to the JSON property instanceOsPoliciesCompliances



1179
1180
1181
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1179

def instance_os_policies_compliances
  @instance_os_policies_compliances
end

#next_page_tokenString

The pagination token to retrieve the next page of instance OS policies compliance objects. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1185

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1192
1193
1194
1195
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1192

def update!(**args)
  @instance_os_policies_compliances = args[:instance_os_policies_compliances] if args.key?(:instance_os_policies_compliances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end