Class: Google::Apis::OsconfigV1alpha::ListOsPolicyAssignmentReportsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

A response message for listing OS Policy assignment reports including the page of results and page token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOsPolicyAssignmentReportsResponse

Returns a new instance of ListOsPolicyAssignmentReportsResponse.



1063
1064
1065
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The pagination token to retrieve the next page of OS policy assignment report objects. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1056

def next_page_token
  @next_page_token
end

#os_policy_assignment_reportsArray<Google::Apis::OsconfigV1alpha::OsPolicyAssignmentReport>

List of OS policy assignment reports. Corresponds to the JSON property osPolicyAssignmentReports



1061
1062
1063
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1061

def os_policy_assignment_reports
  @os_policy_assignment_reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1068
1069
1070
1071
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1068

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @os_policy_assignment_reports = args[:os_policy_assignment_reports] if args.key?(:os_policy_assignment_reports)
end