Class: Google::Apis::OsconfigV1alpha::OsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::OsPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
An OS policy defines the desired state configuration for a VM.
Instance Attribute Summary collapse
-
#allow_no_resource_group_match ⇒ Boolean
(also: #allow_no_resource_group_match?)
This flag determines the OS policy compliance status when none of the resource groups within the policy are applicable for a VM.
-
#description ⇒ String
Policy description.
-
#id ⇒ String
Required.
-
#mode ⇒ String
Required.
-
#resource_groups ⇒ Array<Google::Apis::OsconfigV1alpha::OsPolicyResourceGroup>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicy
constructor
A new instance of OsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicy
Returns a new instance of OsPolicy.
1213 1214 1215 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_no_resource_group_match ⇒ Boolean Also known as: allow_no_resource_group_match?
This flag determines the OS policy compliance status when none of the resource
groups within the policy are applicable for a VM. Set this value to true if
the policy needs to be reported as compliant even if the policy has nothing to
validate or enforce.
Corresponds to the JSON property allowNoResourceGroupMatch
1182 1183 1184 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1182 def allow_no_resource_group_match @allow_no_resource_group_match end |
#description ⇒ String
Policy description. Length of the description is limited to 1024 characters.
Corresponds to the JSON property description
1188 1189 1190 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1188 def description @description end |
#id ⇒ String
Required. The id of the OS policy with the following restrictions: * Must
contain only lowercase letters, numbers, and hyphens. * Must start with a
letter. * Must be between 1-63 characters. * Must end with a number or a
letter. * Must be unique within the assignment.
Corresponds to the JSON property id
1196 1197 1198 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1196 def id @id end |
#mode ⇒ String
Required. Policy mode
Corresponds to the JSON property mode
1201 1202 1203 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1201 def mode @mode end |
#resource_groups ⇒ Array<Google::Apis::OsconfigV1alpha::OsPolicyResourceGroup>
Required. List of resource groups for the policy. For a particular VM,
resource groups are evaluated in the order specified and the first resource
group that is applicable is selected and the rest are ignored. If none of the
resource groups are applicable for a VM, the VM is considered to be non-
compliant w.r.t this policy. This behavior can be toggled by the flag
allow_no_resource_group_match
Corresponds to the JSON property resourceGroups
1211 1212 1213 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1211 def resource_groups @resource_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1218 def update!(**args) @allow_no_resource_group_match = args[:allow_no_resource_group_match] if args.key?(:allow_no_resource_group_match) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @mode = args[:mode] if args.key?(:mode) @resource_groups = args[:resource_groups] if args.key?(:resource_groups) end |