Class: Google::Apis::OsconfigV1alpha::OsPolicyAssignmentInstanceFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Filters to select target VMs for an assignment. If more than one filter criteria is specified below, a VM will be selected if and only if it satisfies all of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyAssignmentInstanceFilter

Returns a new instance of OsPolicyAssignmentInstanceFilter.



1377
1378
1379
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allBoolean Also known as: all?

Target all VMs in the project. If true, no other criteria is permitted. Corresponds to the JSON property all

Returns:

  • (Boolean)


1349
1350
1351
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1349

def all
  @all
end

#exclusion_labelsArray<Google::Apis::OsconfigV1alpha::OsPolicyAssignmentLabelSet>

List of label sets used for VM exclusion. If the list has more than one label set, the VM is excluded if any of the label sets are applicable for the VM. Corresponds to the JSON property exclusionLabels



1356
1357
1358
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1356

def exclusion_labels
  @exclusion_labels
end

#inclusion_labelsArray<Google::Apis::OsconfigV1alpha::OsPolicyAssignmentLabelSet>

List of label sets used for VM inclusion. If the list has more than one LabelSet, the VM is included if any of the label sets are applicable for the VM. Corresponds to the JSON property inclusionLabels



1363
1364
1365
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1363

def inclusion_labels
  @inclusion_labels
end

#inventoriesArray<Google::Apis::OsconfigV1alpha::OsPolicyAssignmentInstanceFilterInventory>

List of inventories to select VMs. A VM is selected if its inventory data matches at least one of the following inventories. Corresponds to the JSON property inventories



1369
1370
1371
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1369

def inventories
  @inventories
end

#os_short_namesArray<String>

Deprecated. Use the inventories field instead. A VM is selected if it's OS short name matches with any of the values provided in this list. Corresponds to the JSON property osShortNames

Returns:

  • (Array<String>)


1375
1376
1377
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1375

def os_short_names
  @os_short_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1382
1383
1384
1385
1386
1387
1388
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1382

def update!(**args)
  @all = args[:all] if args.key?(:all)
  @exclusion_labels = args[:exclusion_labels] if args.key?(:exclusion_labels)
  @inclusion_labels = args[:inclusion_labels] if args.key?(:inclusion_labels)
  @inventories = args[:inventories] if args.key?(:inventories)
  @os_short_names = args[:os_short_names] if args.key?(:os_short_names)
end