Class: Google::Apis::OsconfigV1alpha::OsPolicyResourceCompliance
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::OsPolicyResourceCompliance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
Compliance data for an OS policy resource.
Instance Attribute Summary collapse
-
#config_steps ⇒ Array<Google::Apis::OsconfigV1alpha::OsPolicyResourceConfigStep>
Ordered list of configuration steps taken by the agent for the OS policy resource.
-
#exec_resource_output ⇒ Google::Apis::OsconfigV1alpha::OsPolicyResourceComplianceExecResourceOutput
ExecResource specific output.
-
#os_policy_resource_id ⇒ String
The id of the OS policy resource.
-
#state ⇒ String
Compliance state of the OS policy resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyResourceCompliance
constructor
A new instance of OsPolicyResourceCompliance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyResourceCompliance
Returns a new instance of OsPolicyResourceCompliance.
1881 1882 1883 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_steps ⇒ Array<Google::Apis::OsconfigV1alpha::OsPolicyResourceConfigStep>
Ordered list of configuration steps taken by the agent for the OS policy
resource.
Corresponds to the JSON property configSteps
1864 1865 1866 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1864 def config_steps @config_steps end |
#exec_resource_output ⇒ Google::Apis::OsconfigV1alpha::OsPolicyResourceComplianceExecResourceOutput
ExecResource specific output.
Corresponds to the JSON property execResourceOutput
1869 1870 1871 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1869 def exec_resource_output @exec_resource_output end |
#os_policy_resource_id ⇒ String
The id of the OS policy resource.
Corresponds to the JSON property osPolicyResourceId
1874 1875 1876 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1874 def os_policy_resource_id @os_policy_resource_id end |
#state ⇒ String
Compliance state of the OS policy resource.
Corresponds to the JSON property state
1879 1880 1881 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1879 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1886 1887 1888 1889 1890 1891 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1886 def update!(**args) @config_steps = args[:config_steps] if args.key?(:config_steps) @exec_resource_output = args[:exec_resource_output] if args.key?(:exec_resource_output) @os_policy_resource_id = args[:os_policy_resource_id] if args.key?(:os_policy_resource_id) @state = args[:state] if args.key?(:state) end |