Class: Google::Apis::OsconfigV1alpha::OsPolicyResourceExecResourceExec
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::OsPolicyResourceExecResourceExec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
A file or script to execute.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Optional arguments to pass to the source during execution.
-
#file ⇒ Google::Apis::OsconfigV1alpha::OsPolicyResourceFile
A remote or local file.
-
#interpreter ⇒ String
Required.
-
#output_file_path ⇒ String
Only recorded for enforce Exec.
-
#script ⇒ String
An inline script.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyResourceExecResourceExec
constructor
A new instance of OsPolicyResourceExecResourceExec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyResourceExecResourceExec
Returns a new instance of OsPolicyResourceExecResourceExec.
2234 2235 2236 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Optional arguments to pass to the source during execution.
Corresponds to the JSON property args
2209 2210 2211 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2209 def args @args end |
#file ⇒ Google::Apis::OsconfigV1alpha::OsPolicyResourceFile
A remote or local file.
Corresponds to the JSON property file
2214 2215 2216 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2214 def file @file end |
#interpreter ⇒ String
Required. The script interpreter to use.
Corresponds to the JSON property interpreter
2219 2220 2221 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2219 def interpreter @interpreter end |
#output_file_path ⇒ String
Only recorded for enforce Exec. Path to an output file (that is created by
this Exec) whose content will be recorded in OSPolicyResourceCompliance after
a successful run. Absence or failure to read this file will result in this
ExecResource being non-compliant. Output file size is limited to 100K bytes.
Corresponds to the JSON property outputFilePath
2227 2228 2229 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2227 def output_file_path @output_file_path end |
#script ⇒ String
An inline script. The size of the script is limited to 32KiB.
Corresponds to the JSON property script
2232 2233 2234 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2232 def script @script end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2239 2240 2241 2242 2243 2244 2245 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2239 def update!(**args) @args = args[:args] if args.key?(:args) @file = args[:file] if args.key?(:file) @interpreter = args[:interpreter] if args.key?(:interpreter) @output_file_path = args[:output_file_path] if args.key?(:output_file_path) @script = args[:script] if args.key?(:script) end |