Class: Google::Apis::OsconfigV1alpha::OsPolicyResourceFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

A remote or local file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceFile

Returns a new instance of OsPolicyResourceFile.



2064
2065
2066
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_insecureBoolean Also known as: allow_insecure?

Defaults to false. When false, files are subject to validations based on the file type: Remote: A checksum must be specified. Cloud Storage: An object generation number must be specified. Corresponds to the JSON property allowInsecure

Returns:

  • (Boolean)


2046
2047
2048
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2046

def allow_insecure
  @allow_insecure
end

#gcsGoogle::Apis::OsconfigV1alpha::OsPolicyResourceFileGcs

Specifies a file available as a Cloud Storage Object. Corresponds to the JSON property gcs



2052
2053
2054
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2052

def gcs
  @gcs
end

#local_pathString

A local path within the VM to use. Corresponds to the JSON property localPath

Returns:

  • (String)


2057
2058
2059
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2057

def local_path
  @local_path
end

#remoteGoogle::Apis::OsconfigV1alpha::OsPolicyResourceFileRemote

Specifies a file available via some URI. Corresponds to the JSON property remote



2062
2063
2064
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2062

def remote
  @remote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2069
2070
2071
2072
2073
2074
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2069

def update!(**args)
  @allow_insecure = args[:allow_insecure] if args.key?(:allow_insecure)
  @gcs = args[:gcs] if args.key?(:gcs)
  @local_path = args[:local_path] if args.key?(:local_path)
  @remote = args[:remote] if args.key?(:remote)
end