Class: Google::Apis::OsconfigV1alpha::OsPolicyResourceFileResource
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::OsPolicyResourceFileResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
A resource that manages the state of a file.
Instance Attribute Summary collapse
-
#content ⇒ String
A file with this content.
-
#file ⇒ Google::Apis::OsconfigV1alpha::OsPolicyResourceFile
A remote or local file.
-
#path ⇒ String
Required.
-
#permissions ⇒ String
Consists of three octal digits which represent, in order, the permissions of the owner, group, and other users for the file (similarly to the numeric mode used in the linux chmod utility).
-
#state ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyResourceFileResource
constructor
A new instance of OsPolicyResourceFileResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyResourceFileResource
Returns a new instance of OsPolicyResourceFileResource.
2170 2171 2172 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
A file with this content. The size of the content is limited to 32KiB.
Corresponds to the JSON property content
2141 2142 2143 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2141 def content @content end |
#file ⇒ Google::Apis::OsconfigV1alpha::OsPolicyResourceFile
A remote or local file.
Corresponds to the JSON property file
2146 2147 2148 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2146 def file @file end |
#path ⇒ String
Required. The absolute path of the file within the VM.
Corresponds to the JSON property path
2151 2152 2153 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2151 def path @path end |
#permissions ⇒ String
Consists of three octal digits which represent, in order, the permissions of
the owner, group, and other users for the file (similarly to the numeric mode
used in the linux chmod utility). Each digit represents a three bit number
with the 4 bit corresponding to the read permissions, the 2 bit corresponds to
the write bit, and the one bit corresponds to the execute permission. Default
behavior is 755. Below are some examples of permissions and their associated
values: read, write, and execute: 7 read and execute: 5 read and write: 6 read
only: 4
Corresponds to the JSON property permissions
2163 2164 2165 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2163 def @permissions end |
#state ⇒ String
Required. Desired state of the file.
Corresponds to the JSON property state
2168 2169 2170 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2168 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2175 2176 2177 2178 2179 2180 2181 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2175 def update!(**args) @content = args[:content] if args.key?(:content) @file = args[:file] if args.key?(:file) @path = args[:path] if args.key?(:path) @permissions = args[:permissions] if args.key?(:permissions) @state = args[:state] if args.key?(:state) end |