Class: Google::Apis::OsconfigV1alpha::OsPolicyResourceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Resource groups provide a mechanism to group OS policy resources. Resource groups enable OS policy authors to create a single OS policy to be applied to VMs running different operating Systems. When the OS policy is applied to a target VM, the appropriate resource group within the OS policy is selected based on the OSFilter specified within the resource group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceGroup

Returns a new instance of OsPolicyResourceGroup.



2425
2426
2427
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inventory_filtersArray<Google::Apis::OsconfigV1alpha::OsPolicyInventoryFilter>

List of inventory filters for the resource group. The resources in this resource group are applied to the target VM if it satisfies at least one of the following inventory filters. For example, to apply this resource group to VMs running either RHEL or CentOS operating systems, specify 2 items for the list with following values: inventory_filters[0].os_short_name='rhel' and inventory_filters[1].os_short_name='centos' If the list is empty, this resource group will be applied to the target VM unconditionally. Corresponds to the JSON property inventoryFilters



2412
2413
2414
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2412

def inventory_filters
  @inventory_filters
end

#os_filterGoogle::Apis::OsconfigV1alpha::OsPolicyOsFilter

Filtering criteria to select VMs based on OS details. Corresponds to the JSON property osFilter



2417
2418
2419
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2417

def os_filter
  @os_filter
end

#resourcesArray<Google::Apis::OsconfigV1alpha::OsPolicyResource>

Required. List of resources configured for this resource group. The resources are executed in the exact order specified here. Corresponds to the JSON property resources



2423
2424
2425
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2423

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2430
2431
2432
2433
2434
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2430

def update!(**args)
  @inventory_filters = args[:inventory_filters] if args.key?(:inventory_filters)
  @os_filter = args[:os_filter] if args.key?(:os_filter)
  @resources = args[:resources] if args.key?(:resources)
end