Class: Google::Apis::OsconfigV1alpha::VulnerabilityReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

This API resource represents the vulnerability report for a specified Compute Engine virtual machine (VM) instance at a given point in time. For more information, see Vulnerability reports.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReport

Returns a new instance of VulnerabilityReport.



2839
2840
2841
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highest_upgradable_cve_severityString

Output only. Highest level of severity among all the upgradable vulnerabilities with CVEs attached. Corresponds to the JSON property highestUpgradableCveSeverity

Returns:

  • (String)


2819
2820
2821
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2819

def highest_upgradable_cve_severity
  @highest_upgradable_cve_severity
end

#nameString

Output only. The vulnerabilityReport API resource name. Format: projects/ project_number/locations/location/instances/instance_id/ vulnerabilityReport Corresponds to the JSON property name

Returns:

  • (String)


2826
2827
2828
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2826

def name
  @name
end

#update_timeString

Output only. The timestamp for when the last vulnerability report was generated for the VM. Corresponds to the JSON property updateTime

Returns:

  • (String)


2832
2833
2834
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2832

def update_time
  @update_time
end

#vulnerabilitiesArray<Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerability>

Output only. List of vulnerabilities affecting the VM. Corresponds to the JSON property vulnerabilities



2837
2838
2839
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2837

def vulnerabilities
  @vulnerabilities
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2844
2845
2846
2847
2848
2849
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2844

def update!(**args)
  @highest_upgradable_cve_severity = args[:highest_upgradable_cve_severity] if args.key?(:highest_upgradable_cve_severity)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vulnerabilities = args[:vulnerabilities] if args.key?(:vulnerabilities)
end