Class: Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

A vulnerability affecting the VM instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReportVulnerability

Returns a new instance of VulnerabilityReportVulnerability.



2895
2896
2897
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_inventory_item_idsArray<String>

Corresponds to the AVAILABLE_PACKAGE inventory item on the VM. If the vulnerability report was not updated after the VM inventory update, these values might not display in VM inventory. If there is no available fix, the field is empty. The inventory_item value specifies the latest SoftwarePackage available to the VM that fixes the vulnerability. Corresponds to the JSON property availableInventoryItemIds

Returns:

  • (Array<String>)


2863
2864
2865
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2863

def available_inventory_item_ids
  @available_inventory_item_ids
end

#create_timeString

The timestamp for when the vulnerability was first detected. Corresponds to the JSON property createTime

Returns:

  • (String)


2868
2869
2870
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2868

def create_time
  @create_time
end

#detailsGoogle::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityDetails

Contains metadata information for the vulnerability. This information is collected from the upstream feed of the operating system. Corresponds to the JSON property details



2874
2875
2876
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2874

def details
  @details
end

#installed_inventory_item_idsArray<String>

Corresponds to the INSTALLED_PACKAGE inventory item on the VM. This field displays the inventory items affected by this vulnerability. If the vulnerability report was not updated after the VM inventory update, these values might not display in VM inventory. For some distros, this field may be empty. Corresponds to the JSON property installedInventoryItemIds

Returns:

  • (Array<String>)


2883
2884
2885
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2883

def installed_inventory_item_ids
  @installed_inventory_item_ids
end

#itemsArray<Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityItem>

List of items affected by the vulnerability. Corresponds to the JSON property items



2888
2889
2890
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2888

def items
  @items
end

#update_timeString

The timestamp for when the vulnerability was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


2893
2894
2895
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2893

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2900
2901
2902
2903
2904
2905
2906
2907
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2900

def update!(**args)
  @available_inventory_item_ids = args[:available_inventory_item_ids] if args.key?(:available_inventory_item_ids)
  @create_time = args[:create_time] if args.key?(:create_time)
  @details = args[:details] if args.key?(:details)
  @installed_inventory_item_ids = args[:installed_inventory_item_ids] if args.key?(:installed_inventory_item_ids)
  @items = args[:items] if args.key?(:items)
  @update_time = args[:update_time] if args.key?(:update_time)
end