Class: Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Contains metadata information for the vulnerability. This information is collected from the upstream feed of the operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReportVulnerabilityDetails

Returns a new instance of VulnerabilityReportVulnerabilityDetails.



2948
2949
2950
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cveString

The CVE of the vulnerability. CVE cannot be empty and the combination of should be unique across vulnerabilities for a VM. Corresponds to the JSON property cve

Returns:

  • (String)


2919
2920
2921
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2919

def cve
  @cve
end

#cvss_v2_scoreFloat

The CVSS V2 score of this vulnerability. CVSS V2 score is on a scale of 0 - 10 where 0 indicates low severity and 10 indicates high severity. Corresponds to the JSON property cvssV2Score

Returns:

  • (Float)


2925
2926
2927
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2925

def cvss_v2_score
  @cvss_v2_score
end

#cvss_v3Google::Apis::OsconfigV1alpha::CvsSv3

Common Vulnerability Scoring System version 3. For details, see https://www. first.org/cvss/specification-document Corresponds to the JSON property cvssV3



2931
2932
2933
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2931

def cvss_v3
  @cvss_v3
end

#descriptionString

The note or description describing the vulnerability from the distro. Corresponds to the JSON property description

Returns:

  • (String)


2936
2937
2938
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2936

def description
  @description
end

#referencesArray<Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityDetailsReference>

Corresponds to the references attached to the VulnerabilityDetails. Corresponds to the JSON property references



2941
2942
2943
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2941

def references
  @references
end

#severityString

Assigned severity/impact ranking from the distro. Corresponds to the JSON property severity

Returns:

  • (String)


2946
2947
2948
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2946

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2953
2954
2955
2956
2957
2958
2959
2960
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2953

def update!(**args)
  @cve = args[:cve] if args.key?(:cve)
  @cvss_v2_score = args[:cvss_v2_score] if args.key?(:cvss_v2_score)
  @cvss_v3 = args[:cvss_v3] if args.key?(:cvss_v3)
  @description = args[:description] if args.key?(:description)
  @references = args[:references] if args.key?(:references)
  @severity = args[:severity] if args.key?(:severity)
end