Class: Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityItem
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
OS inventory item that is affected by a vulnerability or fixed as a result of a vulnerability.
Instance Attribute Summary collapse
-
#available_inventory_item_id ⇒ String
Corresponds to the
AVAILABLE_PACKAGEinventory item on the VM. -
#fixed_cpe_uri ⇒ String
The recommended CPE URI update that contains a fix for this vulnerability.
-
#installed_inventory_item_id ⇒ String
Corresponds to the
INSTALLED_PACKAGEinventory item on the VM. -
#upstream_fix ⇒ String
The upstream OS patch, packages or KB that fixes the vulnerability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityReportVulnerabilityItem
constructor
A new instance of VulnerabilityReportVulnerabilityItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityReportVulnerabilityItem
Returns a new instance of VulnerabilityReportVulnerabilityItem.
3022 3023 3024 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_inventory_item_id ⇒ String
Corresponds to the AVAILABLE_PACKAGE inventory item on the VM. If the
vulnerability report was not updated after the VM inventory update, these
values might not display in VM inventory. If there is no available fix, the
field is empty. The inventory_item value specifies the latest
SoftwarePackage available to the VM that fixes the vulnerability.
Corresponds to the JSON property availableInventoryItemId
3000 3001 3002 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3000 def available_inventory_item_id @available_inventory_item_id end |
#fixed_cpe_uri ⇒ String
The recommended CPE URI update that
contains a fix for this vulnerability.
Corresponds to the JSON property fixedCpeUri
3006 3007 3008 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3006 def fixed_cpe_uri @fixed_cpe_uri end |
#installed_inventory_item_id ⇒ String
Corresponds to the INSTALLED_PACKAGE inventory item on the VM. This field
displays the inventory items affected by this vulnerability. If the
vulnerability report was not updated after the VM inventory update, these
values might not display in VM inventory. For some operating systems, this
field might be empty.
Corresponds to the JSON property installedInventoryItemId
3015 3016 3017 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3015 def installed_inventory_item_id @installed_inventory_item_id end |
#upstream_fix ⇒ String
The upstream OS patch, packages or KB that fixes the vulnerability.
Corresponds to the JSON property upstreamFix
3020 3021 3022 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3020 def upstream_fix @upstream_fix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3027 3028 3029 3030 3031 3032 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3027 def update!(**args) @available_inventory_item_id = args[:available_inventory_item_id] if args.key?(:available_inventory_item_id) @fixed_cpe_uri = args[:fixed_cpe_uri] if args.key?(:fixed_cpe_uri) @installed_inventory_item_id = args[:installed_inventory_item_id] if args.key?(:installed_inventory_item_id) @upstream_fix = args[:upstream_fix] if args.key?(:upstream_fix) end |