Class: Google::Apis::OsconfigV1alpha::InstanceOsPoliciesCompliance
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::InstanceOsPoliciesCompliance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
This API resource represents the OS policies compliance data for a Compute Engine virtual machine (VM) instance at a given point in time. A Compute Engine VM can have multiple OS policy assignments, and each assignment can have multiple OS policies. As a result, multiple OS policies could be applied to a single VM. You can use this API resource to determine both the compliance state of your VM as well as the compliance state of an individual OS policy. For more information, see View compliance.
Instance Attribute Summary collapse
-
#detailed_state ⇒ String
Output only.
-
#detailed_state_reason ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#last_compliance_check_time ⇒ String
Output only.
-
#last_compliance_run_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#os_policy_compliances ⇒ Array<Google::Apis::OsconfigV1alpha::InstanceOsPoliciesComplianceOsPolicyCompliance>
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceOsPoliciesCompliance
constructor
A new instance of InstanceOsPoliciesCompliance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceOsPoliciesCompliance
Returns a new instance of InstanceOsPoliciesCompliance.
441 442 443 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detailed_state ⇒ String
Output only. Detailed compliance state of the VM. This field is populated only
when compliance state is UNKNOWN. It may contain one of the following values:
no-compliance-data: Compliance data is not available for this VM. *no- agent-detected: OS Config agent is not detected for this VM. *config-not- supported-by-agent: The version of the OS Config agent running on this VM does not support configuration management. *inactive: VM is not running. *internal-service-errors: There were internal service errors encountered while enforcing compliance. *agent-errors: OS config agent encountered errors while enforcing compliance. Corresponds to the JSON propertydetailedState
400 401 402 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 400 def detailed_state @detailed_state end |
#detailed_state_reason ⇒ String
Output only. The reason for the detailed_state of the VM (if any).
Corresponds to the JSON property detailedStateReason
405 406 407 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 405 def detailed_state_reason @detailed_state_reason end |
#instance ⇒ String
Output only. The Compute Engine VM instance name.
Corresponds to the JSON property instance
410 411 412 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 410 def instance @instance end |
#last_compliance_check_time ⇒ String
Output only. Timestamp of the last compliance check for the VM.
Corresponds to the JSON property lastComplianceCheckTime
415 416 417 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 415 def last_compliance_check_time @last_compliance_check_time end |
#last_compliance_run_id ⇒ String
Output only. Unique identifier for the last compliance run. This id will be
logged by the OS config agent during a compliance run and can be used for
debugging and tracing purpose.
Corresponds to the JSON property lastComplianceRunId
422 423 424 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 422 def last_compliance_run_id @last_compliance_run_id end |
#name ⇒ String
Output only. The InstanceOSPoliciesCompliance API resource name. Format:
projects/project_number/locations/location/instanceOSPoliciesCompliances/
instance_id`
Corresponds to the JSON propertyname`
429 430 431 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 429 def name @name end |
#os_policy_compliances ⇒ Array<Google::Apis::OsconfigV1alpha::InstanceOsPoliciesComplianceOsPolicyCompliance>
Output only. Compliance data for each OSPolicy that is applied to the VM.
Corresponds to the JSON property osPolicyCompliances
434 435 436 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 434 def os_policy_compliances @os_policy_compliances end |
#state ⇒ String
Output only. Compliance state of the VM.
Corresponds to the JSON property state
439 440 441 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 439 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
446 447 448 449 450 451 452 453 454 455 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 446 def update!(**args) @detailed_state = args[:detailed_state] if args.key?(:detailed_state) @detailed_state_reason = args[:detailed_state_reason] if args.key?(:detailed_state_reason) @instance = args[:instance] if args.key?(:instance) @last_compliance_check_time = args[:last_compliance_check_time] if args.key?(:last_compliance_check_time) @last_compliance_run_id = args[:last_compliance_run_id] if args.key?(:last_compliance_run_id) @name = args[:name] if args.key?(:name) @os_policy_compliances = args[:os_policy_compliances] if args.key?(:os_policy_compliances) @state = args[:state] if args.key?(:state) end |