Class: Google::Apis::OsconfigV1alpha::Inventory
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::Inventory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
This API resource represents the available inventory data for a Compute Engine virtual machine (VM) instance at a given point in time. You can use this API resource to determine the inventory data of your VM. For more information, see Information provided by OS inventory management.
Instance Attribute Summary collapse
-
#items ⇒ Hash<String,Google::Apis::OsconfigV1alpha::InventoryItem>
Output only.
-
#name ⇒ String
Output only.
-
#os_info ⇒ Google::Apis::OsconfigV1alpha::InventoryOsInfo
Operating system information for the VM.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Inventory
constructor
A new instance of Inventory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Inventory
Returns a new instance of Inventory.
529 530 531 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Hash<String,Google::Apis::OsconfigV1alpha::InventoryItem>
Output only. Inventory items related to the VM keyed by an opaque unique
identifier for each inventory item. The identifier is unique to each distinct
and addressable inventory item and will change, when there is a new package
version.
Corresponds to the JSON property items
511 512 513 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 511 def items @items end |
#name ⇒ String
Output only. The Inventory API resource name. Format: projects/
project_number/locations/location/instances/instance_id/inventory
Corresponds to the JSON property name
517 518 519 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 517 def name @name end |
#os_info ⇒ Google::Apis::OsconfigV1alpha::InventoryOsInfo
Operating system information for the VM.
Corresponds to the JSON property osInfo
522 523 524 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 522 def os_info @os_info end |
#update_time ⇒ String
Output only. Timestamp of the last reported inventory for the VM.
Corresponds to the JSON property updateTime
527 528 529 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 527 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
534 535 536 537 538 539 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 534 def update!(**args) @items = args[:items] if args.key?(:items) @name = args[:name] if args.key?(:name) @os_info = args[:os_info] if args.key?(:os_info) @update_time = args[:update_time] if args.key?(:update_time) end |