Class: Google::Apis::OsconfigV1alpha::InventorySoftwarePackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Software package information of the operating system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySoftwarePackage

Returns a new instance of InventorySoftwarePackage.



897
898
899
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apt_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property aptPackage



844
845
846
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 844

def apt_package
  @apt_package
end

#cos_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property cosPackage



850
851
852
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 850

def cos_package
  @cos_package
end

#googet_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property googetPackage



856
857
858
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 856

def googet_package
  @googet_package
end

#qfe_packageGoogle::Apis::OsconfigV1alpha::InventoryWindowsQuickFixEngineeringPackage

Information related to a Quick Fix Engineering package. Fields are taken from Windows QuickFixEngineering Interface and match the source names: https://docs. microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering Corresponds to the JSON property qfePackage



863
864
865
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 863

def qfe_package
  @qfe_package
end

#windows_applicationGoogle::Apis::OsconfigV1alpha::InventoryWindowsApplication

Contains information about a Windows application that is retrieved from the Windows Registry. For more information about these fields, see: https://docs. microsoft.com/en-us/windows/win32/msi/uninstall-registry-key Corresponds to the JSON property windowsApplication



870
871
872
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 870

def windows_application
  @windows_application
end

#wua_packageGoogle::Apis::OsconfigV1alpha::InventoryWindowsUpdatePackage

Details related to a Windows Update package. Field data and names are taken from Windows Update API IUpdate Interface: https://docs.microsoft.com/en-us/ windows/win32/api/_wua/ Descriptive fields like title, and description are localized based on the locale of the VM being updated. Corresponds to the JSON property wuaPackage



878
879
880
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 878

def wua_package
  @wua_package
end

#yum_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property yumPackage



884
885
886
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 884

def yum_package
  @yum_package
end

#zypper_packageGoogle::Apis::OsconfigV1alpha::InventoryVersionedPackage

Information related to the a standard versioned package. This includes package info for APT, Yum, Zypper, and Googet package managers. Corresponds to the JSON property zypperPackage



890
891
892
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 890

def zypper_package
  @zypper_package
end

#zypper_patchGoogle::Apis::OsconfigV1alpha::InventoryZypperPatch

Details related to a Zypper Patch. Corresponds to the JSON property zypperPatch



895
896
897
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 895

def zypper_patch
  @zypper_patch
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



902
903
904
905
906
907
908
909
910
911
912
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 902

def update!(**args)
  @apt_package = args[:apt_package] if args.key?(:apt_package)
  @cos_package = args[:cos_package] if args.key?(:cos_package)
  @googet_package = args[:googet_package] if args.key?(:googet_package)
  @qfe_package = args[:qfe_package] if args.key?(:qfe_package)
  @windows_application = args[:windows_application] if args.key?(:windows_application)
  @wua_package = args[:wua_package] if args.key?(:wua_package)
  @yum_package = args[:yum_package] if args.key?(:yum_package)
  @zypper_package = args[:zypper_package] if args.key?(:zypper_package)
  @zypper_patch = args[:zypper_patch] if args.key?(:zypper_patch)
end