Class: Google::Apis::OsconfigV1alpha::OsPolicyAssignmentReport
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::OsPolicyAssignmentReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
A report of the OS policy assignment status for a given instance.
Instance Attribute Summary collapse
-
#instance ⇒ String
The Compute Engine VM instance name.
-
#last_run_id ⇒ String
Unique identifier of the last attempted run to apply the OS policies associated with this assignment on the VM.
-
#name ⇒ String
The
OSPolicyAssignmentReportAPI resource name. -
#os_policy_assignment ⇒ String
Reference to the
OSPolicyAssignmentAPI resource that theOSPolicybelongs to. -
#os_policy_compliances ⇒ Array<Google::Apis::OsconfigV1alpha::OsPolicyAssignmentReportOsPolicyCompliance>
Compliance data for each
OSPolicythat is applied to the VM. -
#update_time ⇒ String
Timestamp for when the report was last generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyAssignmentReport
constructor
A new instance of OsPolicyAssignmentReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyAssignmentReport
Returns a new instance of OsPolicyAssignmentReport.
1531 1532 1533 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance ⇒ String
The Compute Engine VM instance name.
Corresponds to the JSON property instance
1496 1497 1498 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1496 def instance @instance end |
#last_run_id ⇒ String
Unique identifier of the last attempted run to apply the OS policies
associated with this assignment on the VM. This ID is logged by the OS Config
agent while applying the OS policies associated with this assignment on the VM.
NOTE: If the service is unable to successfully connect to the agent for this
run, then this id will not be available in the agent logs.
Corresponds to the JSON property lastRunId
1505 1506 1507 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1505 def last_run_id @last_run_id end |
#name ⇒ String
The OSPolicyAssignmentReport API resource name. Format: projects/
project_number/locations/location/instances/instance_id/
osPolicyAssignments/os_policy_assignment_id/report
Corresponds to the JSON property name
1512 1513 1514 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1512 def name @name end |
#os_policy_assignment ⇒ String
Reference to the OSPolicyAssignment API resource that the OSPolicy belongs
to. Format: projects/project_number/locations/location/
osPolicyAssignments/os_policy_assignment_id@revision_id`
Corresponds to the JSON propertyosPolicyAssignment`
1519 1520 1521 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1519 def os_policy_assignment @os_policy_assignment end |
#os_policy_compliances ⇒ Array<Google::Apis::OsconfigV1alpha::OsPolicyAssignmentReportOsPolicyCompliance>
Compliance data for each OSPolicy that is applied to the VM.
Corresponds to the JSON property osPolicyCompliances
1524 1525 1526 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1524 def os_policy_compliances @os_policy_compliances end |
#update_time ⇒ String
Timestamp for when the report was last generated.
Corresponds to the JSON property updateTime
1529 1530 1531 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1529 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1536 1537 1538 1539 1540 1541 1542 1543 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1536 def update!(**args) @instance = args[:instance] if args.key?(:instance) @last_run_id = args[:last_run_id] if args.key?(:last_run_id) @name = args[:name] if args.key?(:name) @os_policy_assignment = args[:os_policy_assignment] if args.key?(:os_policy_assignment) @os_policy_compliances = args[:os_policy_compliances] if args.key?(:os_policy_compliances) @update_time = args[:update_time] if args.key?(:update_time) end |