Class: Google::Apis::OsconfigV1alpha::OsPolicyOsFilter
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::OsPolicyOsFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
Filtering criteria to select VMs based on OS details.
Instance Attribute Summary collapse
-
#os_short_name ⇒ String
This should match OS short name emitted by the OS inventory agent.
-
#os_version ⇒ String
This value should match the version emitted by the OS inventory agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OsPolicyOsFilter
constructor
A new instance of OsPolicyOsFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OsPolicyOsFilter
Returns a new instance of OsPolicyOsFilter.
1777 1778 1779 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#os_short_name ⇒ String
This should match OS short name emitted by the OS inventory agent. An empty
value matches any OS.
Corresponds to the JSON property osShortName
1767 1768 1769 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1767 def os_short_name @os_short_name end |
#os_version ⇒ String
This value should match the version emitted by the OS inventory agent. Prefix
matches are supported if asterisk() is provided as the last character. For
example, to match all versions with a major version of 7, specify the
following value for this field `7.
Corresponds to the JSON propertyosVersion`
1775 1776 1777 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1775 def os_version @os_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1782 1783 1784 1785 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 1782 def update!(**args) @os_short_name = args[:os_short_name] if args.key?(:os_short_name) @os_version = args[:os_version] if args.key?(:os_version) end |