Class: Google::Apis::OsconfigV1alpha::OsPolicyResourceFileResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

A resource that manages the state of a file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OsPolicyResourceFileResource

Returns a new instance of OsPolicyResourceFileResource.



2381
2382
2383
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

A file with this content. The size of the content is limited to 32KiB. Corresponds to the JSON property content

Returns:

  • (String)


2352
2353
2354
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2352

def content
  @content
end

#fileGoogle::Apis::OsconfigV1alpha::OsPolicyResourceFile

A remote or local file. Corresponds to the JSON property file



2357
2358
2359
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2357

def file
  @file
end

#pathString

Required. The absolute path of the file within the VM. Corresponds to the JSON property path

Returns:

  • (String)


2362
2363
2364
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2362

def path
  @path
end

#permissionsString

Consists of three octal digits which represent, in order, the permissions of the owner, group, and other users for the file (similarly to the numeric mode used in the linux chmod utility). Each digit represents a three bit number with the 4 bit corresponding to the read permissions, the 2 bit corresponds to the write bit, and the one bit corresponds to the execute permission. Default behavior is 755. Below are some examples of permissions and their associated values: read, write, and execute: 7 read and execute: 5 read and write: 6 read only: 4 Corresponds to the JSON property permissions

Returns:

  • (String)


2374
2375
2376
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2374

def permissions
  @permissions
end

#stateString

Required. Desired state of the file. Corresponds to the JSON property state

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2379

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2386
2387
2388
2389
2390
2391
2392
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2386

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @file = args[:file] if args.key?(:file)
  @path = args[:path] if args.key?(:path)
  @permissions = args[:permissions] if args.key?(:permissions)
  @state = args[:state] if args.key?(:state)
end