Class: Google::Apis::OsconfigV1alpha::StatusProto
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::StatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property
canonicalCode. -
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::OsconfigV1alpha::MessageSet
This is proto2's version of MessageSet.
-
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatusProto
constructor
A new instance of StatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatusProto
Returns a new instance of StatusProto.
2794 2795 2796 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 canonical_code = 6;
Corresponds to the JSON property canonicalCode
2758 2759 2760 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2758 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 code = 1;
Corresponds to the JSON property code
2766 2767 2768 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2766 def code @code end |
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara:
strip_end_and_replace optional string message = 3;
Corresponds to the JSON property message
2772 2773 2774 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2772 def @message end |
#message_set ⇒ Google::Apis::OsconfigV1alpha::MessageSet
This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS.
If you are using editions or proto2, please make your own extendable messages
for your use case. If you are using proto3, please use Any instead.
MessageSet was the implementation of extensions for proto1. When proto2 was
introduced, extensions were implemented as a first-class feature. This schema
for MessageSet was meant to be a "bridge" solution to migrate MessageSet-
bearing messages from proto1 to proto2. This schema has been open-sourced only
to facilitate the migration of Google products with MessageSet-bearing
messages to open-source environments.
Corresponds to the JSON property messageSet
2785 2786 2787 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2785 def @message_set end |
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara:
strip_end_and_replace optional string space = 2; // Space to which this status
belongs
Corresponds to the JSON property space
2792 2793 2794 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2792 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2799 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |