Class: Google::Apis::OsconfigV1alpha::StatusProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

Wire-format for a Status object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatusProto

Returns a new instance of StatusProto.



3005
3006
3007
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_codeFixnum

copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property canonicalCode

Returns:

  • (Fixnum)


2969
2970
2971
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2969

def canonical_code
  @canonical_code
end

#codeFixnum

Numeric code drawn from the space specified below. Often, this is the canonical error space, and code is drawn from google3/util/task/codes.proto copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 code = 1; Corresponds to the JSON property code

Returns:

  • (Fixnum)


2977
2978
2979
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2977

def code
  @code
end

#messageString

Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property message

Returns:

  • (String)


2983
2984
2985
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2983

def message
  @message
end

#message_setGoogle::Apis::OsconfigV1alpha::MessageSet

This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS. If you are using editions or proto2, please make your own extendable messages for your use case. If you are using proto3, please use Any instead. MessageSet was the implementation of extensions for proto1. When proto2 was introduced, extensions were implemented as a first-class feature. This schema for MessageSet was meant to be a "bridge" solution to migrate MessageSet- bearing messages from proto1 to proto2. This schema has been open-sourced only to facilitate the migration of Google products with MessageSet-bearing messages to open-source environments. Corresponds to the JSON property messageSet



2996
2997
2998
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 2996

def message_set
  @message_set
end

#spaceString

copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property space

Returns:

  • (String)


3003
3004
3005
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3003

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3010
3011
3012
3013
3014
3015
3016
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3010

def update!(**args)
  @canonical_code = args[:canonical_code] if args.key?(:canonical_code)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @message_set = args[:message_set] if args.key?(:message_set)
  @space = args[:space] if args.key?(:space)
end