Class: Google::Apis::OsconfigV1alpha::VulnerabilityReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb

Overview

This API resource represents the vulnerability report for a specified Compute Engine virtual machine (VM) instance at a given point in time. For more information, see Vulnerability reports.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VulnerabilityReport

Returns a new instance of VulnerabilityReport.



3050
3051
3052
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#highest_upgradable_cve_severityString

Output only. Highest level of severity among all the upgradable vulnerabilities with CVEs attached. Corresponds to the JSON property highestUpgradableCveSeverity

Returns:

  • (String)


3030
3031
3032
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3030

def highest_upgradable_cve_severity
  @highest_upgradable_cve_severity
end

#nameString

Output only. The vulnerabilityReport API resource name. Format: projects/ project_number/locations/location/instances/instance_id/ vulnerabilityReport Corresponds to the JSON property name

Returns:

  • (String)


3037
3038
3039
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3037

def name
  @name
end

#update_timeString

Output only. The timestamp for when the last vulnerability report was generated for the VM. Corresponds to the JSON property updateTime

Returns:

  • (String)


3043
3044
3045
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3043

def update_time
  @update_time
end

#vulnerabilitiesArray<Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerability>

Output only. List of vulnerabilities affecting the VM. Corresponds to the JSON property vulnerabilities



3048
3049
3050
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3048

def vulnerabilities
  @vulnerabilities
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3055
3056
3057
3058
3059
3060
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3055

def update!(**args)
  @highest_upgradable_cve_severity = args[:highest_upgradable_cve_severity] if args.key?(:highest_upgradable_cve_severity)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vulnerabilities = args[:vulnerabilities] if args.key?(:vulnerabilities)
end