Class: Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerability
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1alpha/classes.rb,
lib/google/apis/osconfig_v1alpha/representations.rb,
lib/google/apis/osconfig_v1alpha/representations.rb
Overview
A vulnerability affecting the VM instance.
Instance Attribute Summary collapse
-
#available_inventory_item_ids ⇒ Array<String>
Corresponds to the
AVAILABLE_PACKAGEinventory item on the VM. -
#create_time ⇒ String
The timestamp for when the vulnerability was first detected.
-
#details ⇒ Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityDetails
Contains metadata information for the vulnerability.
-
#installed_inventory_item_ids ⇒ Array<String>
Corresponds to the
INSTALLED_PACKAGEinventory item on the VM. -
#items ⇒ Array<Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityItem>
List of items affected by the vulnerability.
-
#update_time ⇒ String
The timestamp for when the vulnerability was last modified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VulnerabilityReportVulnerability
constructor
A new instance of VulnerabilityReportVulnerability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VulnerabilityReportVulnerability
Returns a new instance of VulnerabilityReportVulnerability.
3106 3107 3108 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_inventory_item_ids ⇒ Array<String>
Corresponds to the AVAILABLE_PACKAGE inventory item on the VM. If the
vulnerability report was not updated after the VM inventory update, these
values might not display in VM inventory. If there is no available fix, the
field is empty. The inventory_item value specifies the latest
SoftwarePackage available to the VM that fixes the vulnerability.
Corresponds to the JSON property availableInventoryItemIds
3074 3075 3076 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3074 def available_inventory_item_ids @available_inventory_item_ids end |
#create_time ⇒ String
The timestamp for when the vulnerability was first detected.
Corresponds to the JSON property createTime
3079 3080 3081 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3079 def create_time @create_time end |
#details ⇒ Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityDetails
Contains metadata information for the vulnerability. This information is
collected from the upstream feed of the operating system.
Corresponds to the JSON property details
3085 3086 3087 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3085 def details @details end |
#installed_inventory_item_ids ⇒ Array<String>
Corresponds to the INSTALLED_PACKAGE inventory item on the VM. This field
displays the inventory items affected by this vulnerability. If the
vulnerability report was not updated after the VM inventory update, these
values might not display in VM inventory. For some distros, this field may be
empty.
Corresponds to the JSON property installedInventoryItemIds
3094 3095 3096 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3094 def installed_inventory_item_ids @installed_inventory_item_ids end |
#items ⇒ Array<Google::Apis::OsconfigV1alpha::VulnerabilityReportVulnerabilityItem>
List of items affected by the vulnerability.
Corresponds to the JSON property items
3099 3100 3101 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3099 def items @items end |
#update_time ⇒ String
The timestamp for when the vulnerability was last modified.
Corresponds to the JSON property updateTime
3104 3105 3106 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3104 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3111 3112 3113 3114 3115 3116 3117 3118 |
# File 'lib/google/apis/osconfig_v1alpha/classes.rb', line 3111 def update!(**args) @available_inventory_item_ids = args[:available_inventory_item_ids] if args.key?(:available_inventory_item_ids) @create_time = args[:create_time] if args.key?(:create_time) @details = args[:details] if args.key?(:details) @installed_inventory_item_ids = args[:installed_inventory_item_ids] if args.key?(:installed_inventory_item_ids) @items = args[:items] if args.key?(:items) @update_time = args[:update_time] if args.key?(:update_time) end |